/***********************************************************************
 * Module:  IXmPlayer.aidl
 * Author:  chadwii
 * Purpose: Defines the Interface IXmPlayer
 ***********************************************************************/
package com.ximalaya.ting.android.opensdk.player.service;

import com.ximalaya.ting.android.opensdk.player.service.IXmDataCallback;
import com.ximalaya.ting.android.opensdk.player.service.IXmPlayerEventDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmAdsEventDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmCommonBusinessDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmPlayHistoryListener;
import com.ximalaya.ting.android.opensdk.model.PlayableModel;
import com.ximalaya.ting.android.opensdk.model.track.Track;
import com.ximalaya.ting.android.opensdk.model.history.HistoryModel;
import com.ximalaya.ting.android.opensdk.model.live.radio.Radio;
import com.ximalaya.ting.android.opensdk.model.live.program.Program;
import com.ximalaya.ting.android.opensdk.model.live.schedule.Schedule;
import com.ximalaya.ting.android.opensdk.model.category.CategoryModel;
import com.ximalaya.ting.android.opensdk.player.service.IXmFlvDataCallback;
import com.ximalaya.ting.android.opensdk.player.service.IMixPlayerEventDispatcher;
import com.ximalaya.ting.android.opensdk.player.simplePlayer.mixplay.MixTrack;
import com.ximalaya.ting.android.opensdk.model.xdcs.CdnConfigModel;
import com.ximalaya.ting.android.opensdk.model.statistic.RecordModel;
import  com.ximalaya.ting.android.opensdk.player.service.IXmTokenInvalidForSDKCallBack;
import com.ximalaya.ting.android.opensdk.model.token.AccessToken;
import com.ximalaya.ting.android.opensdk.httputil.Config;
import com.ximalaya.ting.android.opensdk.model.configure.ConfigWrapItem;
import com.ximalaya.ting.android.opensdk.model.ad.AdPreviewModel;
import com.ximalaya.ting.android.opensdk.model.ad.SoundPatchInfo;
import com.ximalaya.ting.android.opensdk.model.soundpatch.SimpleSoundPatchInfo;
import com.ximalaya.ting.android.opensdk.player.manager.ISoundPatchStatusDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmPlayerBaseInfoRequestDispatcher;
import com.ximalaya.ting.android.opensdk.model.advertis.Advertis;
import com.ximalaya.ting.android.opensdk.model.advertis.AdvertisList;
import com.ximalaya.ting.android.opensdk.model.task.TaskStatusInfo;
import com.ximalaya.ting.android.opensdk.player.service.IXmPlanTerminateListener;
import com.ximalaya.ting.android.opensdk.player.ubt.IUbtSourceSynchronizer;

interface IXmPlayer {
   
   //*******************************************播放器所用***************************************
   void playPre();
   void playNext();
   void play(int index);
   void setPlayIndex(int index);
   void startPlay();
   void pausePlay();
    void pausePlayAndCloseNotification();
    void reShowClosedNotification();
   void stopPlay();
   void seekTo(int ms);
   boolean isOnlineSource();
   boolean hasPreSound();
   boolean hasNextSound();
   int getPlayerStatus();
   int getCurrIndex();
   int getDuration();
   int getPlayCurrPosition();
   boolean isPlaying();
   boolean isAdsActive();
   void updateTrackDownloadUrlInPlayList(inout Track track);
   boolean updateTrackInPlayList(inout Track track);
   boolean updateTrackListInPlayList(inout List<Track> trackList);
   Track getTrack(int index);
   Radio getRadio();
   int getPlaySourceType();
   void setPlayMode(String mode);
   String getPlayMode();
   void setPageSize(int pageSize);
   void setPlayList(in Map param, in List<Track> list);
   // 因为IPC通信机制限制只能传递1M所以setPlayList暂时只能传递100个超过的话就将其拆分循环插入 ,执行这个函数之前一定要先执行setPlayList
   void addPlayList(in List<Track> list);
   void playRadio(in Radio radio);
   // position表示第几次请求 ,position从0开始计算
   List<Track> getPlayList(in int position);
   Map getParam();
   int getPlayListSize();
   void clearPlayCache();
   void setNotification(int id, in Notification notification);
   void setAppSecret(String secret);
   void setCanPlayOneKeyPatch(boolean canPlayOneKeyPatch);
   void registePlayerListener(IXmPlayerEventDispatcher l);
   void unregistePlayerListener(IXmPlayerEventDispatcher l);
   void registeAdsListener(IXmAdsEventDispatcher l);
   void unregisteAdsListener(IXmAdsEventDispatcher l);
   void registeCommonBusinessListener(IXmCommonBusinessDispatcher l);
   void getNextPlayList();
   void getPrePlayList();
   void setPlayListChangeListener(IXmDataCallback l);
   boolean permutePlayList();
   boolean getPlayListOrder();
   String getCurPlayUrl(); 
   //*******************************************播放器所用***************************************
   
   //*******************************************请在以下加入非第三方使用的aidl接口***************************************
   void setDLNAState(boolean isDLNAState);
   boolean isDLNAState();
   void needContinuePlay(boolean flag);

   void setRecordModel(inout RecordModel model);
   void setVolume(float leftVolume, float rightVolume);
   float getVolume();
   void setPlayCdnConfigureModel(in CdnConfigModel cdnConfigure);
   void resetPlayList();
   void resetPlayListForRestoreToMainPlayer();
   void removeListByIndex(int index);
   String getHistoryPos(String historyIds);
   void setHistoryPosById(long historyId,int hisPosition);
   String getLastPlayTrackInAlbum(String albumId);
   // 设置播放进程的请求环境(开发环境environmentId=2，测试环境environmentId=4，线上环境environmentId=1)
   void setPlayerProcessRequestEnvironment(int environment);
   void updateLoginInfoOnChange(boolean isLogin);   // 更新登录状态
//   void setStaticDomainServerIpCallBack(IXmStrDataCallBack l);//设置从主进程获取httpDns的回调
   void updateXmPlayResource(String xmPlayResource);//设置当前主进程的playresource
   void updateXmResourceParams(in Map params);//设置当前主进程当前的资源位信息
   void setTempo(float tempo);
   void requestSoundAd(boolean isPaused);   // 请求声音贴片广告
   void pausePlayInMillis(long millis);  // 在多少毫秒之后暂停播放 ,传入-1 表示播放完当前停止播放
   boolean isAdPlaying();   // 广告是否正在播放中
   boolean isTrackPlaying();
   boolean isPlayingConsiderMixPlayer();
   boolean haveNextPlayList();   // 是否有下一页
   boolean havePrePlayList();   // 是否有上一页
   boolean isBuffering();   // 是否正在缓冲中
   void setProxyNew(inout Config config); // 设置代理
   void exitSoundAd(); // 跳过广告
   boolean isLoading(); // 是否正在缓冲中(广告请求中,广告缓冲中,音频缓冲中)

   int getTrackIndex(long trackId);

   //历史记录相关
   void syncCloudHistory(boolean isNeedToPull); //同步服务列表
   void clearAllPlayHistory(boolean deleteCloudy);
   void deletePlayHistory(in HistoryModel historyModel);
   void batchDeleteHistory(in List<HistoryModel> historyModels);
   void markAllHistoryDeleted(boolean onlyRadio);
   void deleteRadioHistory(in Radio radio);
   Track getTrackByHistory(long albumId);
   Radio getHistoryInfoByRadioID(long albumId);
   List<HistoryModel> getTrackList();
   List<HistoryModel> getTrackListHis(int size);
   List<Radio> getHisRadioList();
   void setSkipNextPlayedSound(boolean skip);
   void clearPlayList();
   void registePlayHistoryListener(IXmPlayHistoryListener l);
   int getAlbumSortByAlbumId(long albumId);
   void putAlbumSortByAlbumId(long albumId, int order);
   int getHistoryTrackListSize();
   void clearAllLocalHistory();
   void setPlayFragmentIsShowing(boolean isShowing);
   void resetPlayer(); // 重置播放器
   void setCheckAdContent(boolean willCheck); // 是否检查广告内容
   void onVideoAdCompleted(int curPos ,int duration);   // 当视频广告播放完成之后
//   void unregisteAdsListener(IXmPlayHistoryListener l);
   void insertPlayListHead(in List<Track> list);//在播放列表头部插入数据
    long getCurrentTrackPlayedDuration();
    void setFreeFlowType(int type); // 设置免流type
   void setIsUsingFreeFlow(boolean isUsingFreeFlow);  // 设置是否正在使用免流
   void putSoundHistory(in Track track);
   void saveSoundHistoryPos(long trackId, int playPos);
   void onVideoPlayEnd(in Track track, int breakSec, int playDurationSec);
   void onSwitchInAudio(int switchInSec);
   void onSwitchOutAudio(int switchOutSec);
   Map getDubPlayStatistics();
   void setTrackToNext(in Track track);   // 添加track到下一曲
   void setFlvDataCallBack(IXmFlvDataCallback l);
   int getTrackBufferPercentage();

   void setNotificationType(int type);

   void setCurAdVideoPlayCurPos(int curPos ,int duration);   // 设置当前的视频广告的位置和总的时长

   void setNotificationAfterKilled();

   void setMediaSessionBgViewShow(boolean show);// 设置是否显示系统锁屏背景图

   Track getCurTrack();

   void setAutoPlayAfterGetPlayUrl(boolean autoPlay);

   // 是否开启音量平衡
   void setVolumeBalance(boolean isOpen);

   // 获取音频临时焦点
   void setAudioFocusAtStartStateAtTransient();

   void setLoggerEnable(boolean loggerEnable ,boolean playerLoggerEnable);
   void setContinuePlayWhileAuditionTrackPlayComplete(boolean flag);
   boolean isContinuePlayWhileAuditionTrackPlayComplete();

   void setNetMonitorEnable(boolean enable);

   float getTempo();

   void setPageId(int pageId);

   // **** mix player begin *******
   void createMixPlayerService();
   void destroyMixPlayerService();
   void newMixPlayer(double key);
   void setMixConfig(in Map params);
   void setMixDataSource(double key, String url);
   void setMixDataSourceInfo(in Map params, double iskey);
   Map getMixDataSourceInfo(double key);
   void setMixVolume(double key, float left, float right);
   void setMixLooper(double key, boolean isLoop);
   void setMixSpeed(double key, float speed);
   void startMixPlayer(double key);
   void pauseMixPlayer(double key);
   void stopMixDelay(long mills);
   void seekToMixPlayer(double key, int seek);
   void stopMixPlayer(double key);
   void setMixStartPosition(double key, int start);
   long getMixCurPosition(double key);
   long getMixDuration(double key);
   Map getDelayMillsInfo();
   int getMixCurPercent();
   List getMixPlayerKeys();
   String getMixPlaySource(double key);
   MixTrack getMixPlayTrack();
   void clearMixPlayTrack();
   boolean isMixPlaying(double key);
   boolean isMixerPlaying();
   void playMixerPlayer();
   void pauseMixerPlayer();
   void releaseMixPlayer(double key);
   void registeMixPlayerListener(IMixPlayerEventDispatcher listener);
   void unregisteMixPlayerListener(IMixPlayerEventDispatcher listener);
   // **** mix player end *******

    // *** 配置中心item 传递 ****
    void configureItem(in ConfigWrapItem item);
    // *** 配置中心item 传递 end ***

    // 传递配置中心的信息到收听Festival818任务管理
    void notifyFestivalTaskService(in TaskStatusInfo info);

    void setPreviewAdSource(in AdPreviewModel adPreviewModel);

    void setChannelJumpOver(boolean jumpOver);

    void setValueToPlayProcess(String key ,String value);

    void updateOnGetListenTime();

    void updateSkipHeadTail(long albumId, int head, int tail);

    // 设置播放音质
    void setTrackPlayQualityLevel(int trackQuality);

    void setTrackByTimbreType(String type);

    void setCommercialSoundPatchWorkMode(int mode);

    void registerCommercialSoundPatch(int type, in SimpleSoundPatchInfo simpleInfo);

    void playCommercialSoundPatchByType(int type, String paramsJsonString);

    boolean isPlayingCommercialSoundPatch();

    void stopCommercialSoundPatch();

    void resetCommercialSoundPatchOnVideoAdPlay();

    void addSoundPatch(in SoundPatchInfo soundPatchInfo);

    void appendSoundPatch(in SoundPatchInfo soundPatchInfo);

    void removeSoundPatch(in SoundPatchInfo soundPatchInfo);

    void stopSoundPatch();

    void registerSoundPatchStateListener(ISoundPatchStatusDispatcher dispatch);

    void registerBaseInfoListener(IXmPlayerBaseInfoRequestDispatcher dispatch);

    Track getNextTrack();

    Track getPreTrack();

    int getLimitTime();

    void setLimitTime(int limitTime);

    List<Advertis> getForwardAd();

    AdvertisList getCurSoundAdList();

    Advertis getCurSoundAd();

    void setPlayScene(int playScene);//播放场景 用于区分驾驶模式播放统计

    int getPlayScene();//播放场景 用于区分驾驶模式播放统计

    // vip状态发生变化 hasLogin:当前的登录状态  isVip:当前是否是vip
    void useStatusChange(boolean hasLogin, boolean isVip);

    void updateSubscribeStatus(long albumId, boolean collect);

    void setElderlyMode(boolean elderlyMode);   //设置老年模式

    void changeNotificationStyle(int style);

    void updateDecoderState();  // 更新解码状态

    void onElderlyModelChange();// 老年模式状态变更

    void onVideoAdShow(boolean videoAdHasCached);   // 当视频广告开始展示

    boolean canSoundAdDuringRequest(boolean isPaused);  // 广告是否可以二次曝光请求

    // *** 定时关闭 start ****
    void setPlanTerminateListener(IXmPlanTerminateListener listener);
    String getPlanTerminateContinueStr();
    int[] getLastPlanTerminateType();
   	void setPlanTerminateMode(int mode);
   	void startPlanTerminateTimer(int type);
   	void startPlanTerminateCustomTimer(long time);
    int getPlanTerminatePlayTimes();
   	int getPlanTerminateTimerType();
    void planTerminateCountDown();
   	void planTerminateReset();
   	void planTerminateRelease();
   	void planTerminateForceCancel();
    // *** 定时关闭 end ****

    void setUbtSourceSynchronizer(IUbtSourceSynchronizer synchronizer);
    void onUbtSourceChanged(String type);

   //*******************************************请在以上加入非第三方使用的aidl接口***************************************
}